## Employment data
library(tidyverse)
library(magrittr)
library(readxl)

# Define countries to be used in Data
g7 <- c("United States","Canada","Japan","Germany","United Kingdom","Italy","France")
europe <- c("Germany","United Kingdom","Italy","France")

# Read Brazillian productivity data
br_data <- read_xlsx("productivity_br.xlsx")

# Read employment data of the G7 countries
#    Change Variable classes to the desired ones
#    Remove extra description of Germany name
#    Rename the total economy sector
#    Multiply employment on european countries by 1000 (they were in "thousands of employed people" unit, while US and Japan were in "employed people" unit)
#    Change the dataframe format
employment <- readRDS("national_accounts.rds") %>%
  mutate(geo_name = as.character(geo_name),
         nace_r2_name = as.character(nace_r2_name),
         year = as.numeric(year)) %>%
  mutate(country = case_when(str_detect(string = geo_name, 
                                        pattern = "Germany") ~ str_split_i(geo_name," \\(",1),
                              T ~ geo_name),
         activity = case_when(nace_r2_name == "Total - all NACE activities"~ "total",
                              T ~ str_to_lower(nace_r2_name))) %>%
  filter(country %in% g7,
         activity %in% c("manufacturing","total")) %>%
  mutate(EMP = case_when(country %in% europe ~ EMP*1000,
                         T ~ EMP)) %>%
  select(country, activity, year, emp = EMP) %>%
  pivot_wider(id_cols = c("country", "year"),
              names_from = "activity",values_from = "emp") %>%
  mutate(index = paste0(country, "-", year)) %>%
  mutate(manufacturing = as.numeric(manufacturing),
         total = as.numeric(total)) %>%
  filter(!(country %in% c("Canada", "United States")))

# Read OECD employment data
#    Select desired variables
#    Rename activities
#    Change dataframe format
oecd_g7_employment <- read_csv("oecd_g7_employment.csv") %>%
  select(country = "Reference area", 
         activity = "Economic activity",
         year = "TIME_PERIOD", 
         emp = "OBS_VALUE") %>% 
  mutate(activity = case_when(activity == "Manufacturing" ~ "manufacturing",
                              T ~ "total")) %>%
  pivot_wider(id_cols = c("country", "year"),
              names_from = activity,
              values_from = emp) %>%
  filter(!(country %in% c("Canada", "United States")),
         year <= 2022)

################
### BLS Data ###
################

# Extract US Employment data from the Bureau of Labor Statistics (BLS)

bls_raw <- read_xlsx("bls_employment.xlsx",
                     sheet = "MachineReadable")
  
# Read US Employment Data for the Manufacturing Sector
bls <- bls_raw %>%
  filter(Sector == "Manufacturing", 
         Measure == "Employment", 
         Units == "Thousands of jobs",
         Year >= 1995,
         Digit == "3-Digit") %>%
  mutate(Value = Value*1000) %>%
  group_by(Year, Sector) %>%
  summarise(emp_manufacturing = sum(Value))

# Read US Employment Data for the whole economy, excluding the government
bls_total <- bls_raw %>%
  filter(Measure == "Employment", 
         Units == "Thousands of jobs",
         Year >= 1995,
         Digit == "3-Digit") %>%
  mutate(Value = Value*1000) %>%
  group_by(Year) %>%
  summarise(emp_total = sum(Value))

# Read US Employment Data for the government
bls_gov <- bls_raw %>%
  filter(Measure == "Employment", 
         Units == "Thousands of jobs",
         Year >= 1995,
         Digit == "Custom",
         NAICS == "901") %>%
  mutate(Value = Value*1000) %>%
  group_by(Year) %>%
  summarise(emp_gov = sum(Value))

# Merge US Employment Data for the government with employment data for the whole economy
bls_total %<>% full_join(bls_gov, by = "Year") %>% 
  mutate(emp_total = emp_total + emp_gov) %>%
  full_join(bls, by = "Year") %>%
  mutate(country = "United States") %>%
  mutate(index = paste0(country, "-", Year))%>%
  select(year = Year, total = emp_total, manufacturing = emp_manufacturing, country,index)

# Read Canada Employment data
canada_emp <- read_csv("canada_employment.csv",skip = 12) %>%
  drop_na() %>%
  rename(industries = `North American Industry Classification System (NAICS) 5`) %>%
  filter(industries %in% c("Manufacturing","Total, all industries 6")) %>%
  pivot_longer(names_to = "year",values_to = "value", cols = -industries) %>%
  mutate(value = str_replace_all(value,",","" )) %>%
  mutate(value = as.numeric(value)*1000,
         year = as.numeric(year)) %>%
  pivot_wider(names_from = industries,
              values_from = value) %>%
  rename(total = `Total, all industries 6`,
         manufacturing = Manufacturing) %>%
  mutate(country = "Canada",
         index = paste0(country, "-", year))

# Fetch the 2020 employment values from the EUKLEMS dataset
emp_2020 <- employment %>% 
  filter(year == 2020) %>%
  select(country, manufacturing_2020 = manufacturing, total_2020 = total)

# Fetch the 2020 employment values from the OECD dataset
oecd_2020 <- oecd_g7_employment %>%
  filter(year == 2020) %>%
  select(country, oecd_manufacturing_2020 = manufacturing, oecd_total_2020 = total)

# This part of the code will rebase oecd dataset values by dividing the countries 
#    observations by its 2020 values from the oecd dataset and then multiplying it
#    by its 2020 values from EUKLEMS
oecd_g7_employment_rebased <- oecd_g7_employment %>%
  left_join(oecd_2020, by = "country") %>%
  mutate(
    manufacturing = (manufacturing / oecd_manufacturing_2020) * 100,
    total = (total / oecd_total_2020) * 100) %>%
  filter(!(country %in% c("Canada", "United States"))) %>%
  left_join(emp_2020, by = "country") %>%
  mutate(manufacturing = manufacturing * manufacturing_2020/100,
         total = total* total_2020/100) %>% 
  select(country, year, manufacturing, total) %>%
  mutate(index = paste0(country,"-",year)) %>%
  filter(year > 2020)

# Now it merges the original EUKLEMS tidy dataset with the new oecd rebased dataset
employment %<>% select(country, year, manufacturing, total, index) %>%
  filter(!(country %in% c("United States","Canada")))%>% 
  bind_rows(oecd_g7_employment_rebased) %>%
  bind_rows(bls_total) %>%
  bind_rows(canada_emp) %>%
  select(country, year, emp_manufacturing = manufacturing, emp_total = total, index)

# Reads GDP data from the UN
gdp <- read_xlsx("un_value_added.xlsx") %>%
  select("va_manufacturing" = `Manufacturing (ISIC D)`,
         "country" = `Country/Area`,
         Year,
         "va_total" = `Total Value Added`) %>%
  mutate(country = case_when(country == "United Kingdom of Great Britain and Northern Ireland" ~ "United Kingdom",
                             T ~ country)) %>%
  mutate(year = as.numeric(Year),
         manufacturing = as.numeric(va_manufacturing),
         total = as.numeric(va_total)) %>%
  select(year, manufacturing, total, country) %>%
  mutate(index = paste0(country, "-", year))

# Keep only gdp observations that correspond to emplyoment observations
gdp %<>% filter(index %in% unique(employment$index))

# Keep only employment observations that correspond to gdp observations
employment %<>% filter(index %in% unique(gdp$index))

# Takes gdp and employment data merged together. Aggregates all country observations 
#     into one. Then calculate productivity statistics for the G7 aggregate and 
#     merges it with brazilian data.
data <- gdp %>% full_join(employment, by = c("year", "country")) %>%
  group_by(year) %>%
  summarise(gdp_total = sum(total),                                      
            gdp_manufacturing = sum(manufacturing),                      
            emp_total = sum(emp_total),                                  
            emp_manufacturing = sum(emp_manufacturing),                  
            country = "G7") %>%
  mutate(prod_manufacturing = gdp_manufacturing/emp_manufacturing*100,    
         prod_total = gdp_total/emp_total*100,                            
         gdp_ratio = gdp_manufacturing/gdp_total*100,                     
         prod_ratio = prod_manufacturing/prod_total*100,                  
         emp_ratio = emp_manufacturing/emp_total*100) %>%
  select(year, country, prod_ratio, emp_ratio, gdp_ratio) %>%
  rbind(br_data)



writexl::write_xlsx(data, "productivity_final_data.xlsx")

