library(lubridate)
library(tidyverse)
library(magrittr)
library(readxl)

################
##    Data    ##
################

height = 11             # Define Figure height
width = 15              # Define Figure width
fontsize = 12           # Define Font size
font = "LM Roman 10"    # Define Font
angle = 25              # Define angle of x-axis tick labels

# Define date breaks for the x-axis
date_breaks <- seq(from = ymd('1995-01-01'), to = ymd('2022-10-01'), by = '3 years')

# Read data
data <- read_xlsx("data.xlsx",skip = 1,sheet = "MachineReadable") %>%
 mutate(time = yq(paste0(year, "-Q", quarter))) %>% filter(year <= 2022)

# Read productivity data 
prod_data <- read_xlsx("productivity_final_data.xlsx") %>%
  filter(!(country == "G6" & year == 2023))

#################
##    Plots    ##
#################

# Figure 1
fig1 <- ggplot(data = data) +
  geom_line(mapping = aes(x = time, y = ind_brazil_constant, color = "Constant Prices")) +
  geom_line(mapping = aes(x = time, y = ind_brazil_current, color = "Current Prices")) +
  scale_x_date(breaks = date_breaks, date_labels = "%Y.%d",
               date_minor_breaks = "4 months",
               guide = guide_axis(angle = angle)) +
  labs(x = "Quarter",
       y = "Percentage", 
       color = "Price") + 
  scale_color_manual(values = c("Constant Prices" = "blue", "Current Prices" = "red")) +
  theme_bw() +
  theme(text=element_text(family=font, size=fontsize)) +
    theme(legend.position = "bottom",plot.title = element_text(size = rel(0.8)))
  
# Save Figure 1
ggsave(fig1, width = width, height = height, units = "cm", filename = "output//fig1.png")

# Figure 2
fig2 <- ggplot(data = data) +
  geom_line(mapping = aes(x = time, y = tot), color = "darkblue") +
  scale_x_date(breaks = date_breaks, date_labels = "%Y.%d",
               date_minor_breaks = "4 months",
               guide = guide_axis(angle = angle)) +
  labs(x = "Quarter", 
       y = "Index (2015.1 = 100)") + 
 theme_bw() +   
  theme(text=element_text(family=font, size=fontsize)) +
  theme(plot.title = element_text(size = rel(0.8)))

# Save Figure 2
ggsave(fig2, width = width, height = height, units = "cm", filename = "output//fig2.png")

# Figure 3
fig3 <- ggplot(data = data) +
  geom_line(mapping = aes(x = time, y = rer), color = "darkblue") +
  scale_x_date(breaks = date_breaks, date_labels = "%Y.%d", 
               date_minor_breaks = "4 months",
               guide = guide_axis(angle = angle)) +
  labs(x = "Quarter",
       y = "Index (2015.1 = 100)") + 
  theme_bw() +
  theme(text=element_text(family=font, size=fontsize)) +
  theme(plot.title = element_text(size = rel(0.8)))

# Save Figure 3
ggsave(fig3, width = width, height = height, units = "cm", filename = "output//fig3.png")

# Figure 4
fig4 <- ggplot(data = data) +
  geom_line(mapping = aes(x = time, y = rbdi), color = "darkblue") +
  scale_x_date(breaks = date_breaks, date_labels = "%Y.%d", 
               date_minor_breaks = "4 months",
               guide = guide_axis(angle = angle)) +
  labs(x = "Quarter",
       y = "Index (2015.1 = 100)") + 
  theme_bw() +
  theme(text=element_text(family=font, size=fontsize)) +
  theme(plot.title = element_text(size = rel(0.8)))

# Save Figure 4
ggsave(fig4, width = width, height = height, units = "cm", filename = "output//fig4.png")

# Figure 5
fig5 <- ggplot(data = data) +
  geom_line(mapping = aes(x = time, y = ind_oecd_constant, color = "Constant Prices")) +
  geom_line(mapping = aes(x = time, y = ind_oecd_current, color = "Current Prices")) +
  scale_x_date(breaks = date_breaks, date_labels = "%Y.%d",
               date_minor_breaks = "4 months",
               guide = guide_axis(angle = angle)) +
  labs(x = "Quarter",
       y = "Percentage", 
       color = "Price") + 
  scale_color_manual(values = c("Constant Prices" = "blue", "Current Prices" = "red")) +
  theme_bw() +
  theme(text=element_text(family=font, size=fontsize)) +
    theme(legend.position = "bottom",         plot.title = element_text(size = rel(0.8)))

# Save Figure 5
ggsave(fig5, width = width, height = height, units = "cm", filename = "output//fig5.png")

# Figure 6
fig6 <- ggplot(data = data) +
  geom_line(mapping = aes(x = time, y = rel_prices_brazil, color = "Brazil Relative Prices")) +
  geom_line(mapping = aes(x = time, y = rel_prices_oecd, color = "OECD Relative Prices")) +
  scale_x_date(breaks = date_breaks, date_labels = "%Y.%d",
               date_minor_breaks = "4 months",
               guide = guide_axis(angle = angle)) +
  labs(x = "Quarter",
       y = "Index (2015.1 = 100)", 
       color = "Price") + 
  scale_color_manual(values = c("Brazil Relative Prices" = "blue", "OECD Relative Prices" = "red")) +
  theme_bw() +
  theme(text=element_text(family=font, size=fontsize)) +
    theme(legend.position = "bottom",
          plot.title = element_text(size = rel(0.8)))

# Save Figure 6
ggsave(fig6, width = width, height = height, units = "cm", filename = "output//fig6.png")

# Figure 7
fig7 <- ggplot(data = prod_data) +
  geom_line(mapping = aes(x = year, y = prod_ratio/100, colour = country))  +
  scale_colour_manual(values = c("Brazil" = "darkgreen",
                                 "G7" = "blue")) +
  scale_y_continuous(breaks = seq(from = 0.8, to = 1.5, by = 0.1)) +
  scale_x_continuous(breaks = seq(from = 1995, to = 2023, by = 4)) +
  labs(x = "Year", 
       y = "Productivity Ratio",
       color = "Country") +
  theme_bw() +
  theme(legend.position = "bottom",
        plot.title = element_text(size = rel(0.8)))

# Save Figure 7
ggsave(fig7, width = width, height = height, units = "cm", filename = "output//fig7.png")

# Figure 8
fig8 <- ggplot(data = prod_data) +
  geom_line(mapping = aes(x = year, y = gdp_ratio ,colour = "Manufacturing Share in Aggregate Output")) +
  geom_line(mapping = aes(x = year, y = emp_ratio, colour = "Relative Manufacturing Employment")) +
  scale_color_manual(values = c("Manufacturing Share in Aggregate Output" = "black", "Relative Manufacturing Employment" = "red")) +
  labs(x = "Year", 
       y = "Percentage (%)",
       color = element_blank()) +
  theme_bw() +
  theme(legend.position = "bottom",
        plot.title = element_text(size = rel(0.8))) +
  scale_x_continuous(breaks = seq(from = 1995, to = 2023, by = 4)) +
  facet_wrap(~ country, ncol = 2)

# Save Figure 8
ggsave(fig8, width = width, height = height, units = "cm", filename = "output//fig8.png")

# Figure B1
figB1 <- ggplot(data = data) +
  geom_rect(data=NULL,
            aes(xmin=as_date("1995-01-01"),
                xmax=as_date("1999-01-01"),
                ymin=-Inf,
                ymax=Inf),
            fill="lightblue")+
  geom_rect(data=NULL,
            aes(xmin=as_date("2002-04-01"),
                xmax=as_date("2003-04-01"),
                ymin=-Inf,
                ymax=Inf),
            fill="lightblue")+
  geom_rect(data=NULL,
            aes(xmin=as_date("2020-01-01"),
                xmax=as_date("2022-01-01"),
                ymin=-Inf,
                ymax=Inf),
            fill="lightblue")+
  geom_line(mapping = aes(x = time, y = rer, colour = "RER")) +  
  geom_line(mapping = aes(x = time, y = reer, colour = "REER")) + 
  scale_color_manual(values = c("RER" = "blue", "REER" = "red")) +
  scale_x_date(breaks = date_breaks, date_labels = "%Y.%d", 
               date_minor_breaks = "4 months",
               guide = guide_axis(angle = angle)) +
  labs(x = "Quarter",
       y = "Index (2015.1 = 100)",
       color = element_blank()) + 
  theme_bw() +
  theme(text=element_text(family=font, size=fontsize)) +
  theme(legend.position = "bottom",
        plot.title = element_text(size = rel(0.8)))

# Save Figure B1
ggsave(figB1, width = width, height = height, units = "cm", filename = "output//figB1.png")

