library(tidyverse)
library(readxl)
library(estimatr)
library(kableExtra)
library(gt)
library(ggpubr)

source("helper_functions.R")
data <- read_xlsx("data.xlsx",skip = 1, sheet = "MachineReadable") %>% filter(year <= 2022)

#################################
####  Regression Estimation  ####
#################################

# Estimate First Stage Regression
#   This is column (1) of table 1
first_stage_cons <- lm(data = data,
                       formula = rer ~ rbdi + tot + d_managed + d_lula + d_covid)

# Estimate First Stage Regression
#   This is column (1) of table B1
first_stage_cons_reer <- lm(data = data,
                       formula = reer ~ rbdi + tot 
                       + d_managed + d_lula + d_covid)

############ Second Stage

# We need to eliminate the first 4 observations, because for the fourth lag of the 
#   ind_brazil_constant, the first 4 observations are NA values
l=4

# Create the third lag of the terms of trade
lag3_tot_cons <- lag(data$tot, n = 3)[-(1:l)]

# Create the lags of the brazilian industrialization rate
lag_ind_cons <- lag(data$ind_brazil_constant, n = 1)[-(1:l)]
lag2_ind_cons <- lag(data$ind_brazil_constant, n = 2)[-(1:l)]
lag3_ind_cons <- lag(data$ind_brazil_constant, n = 3)[-(1:l)]
lag4_ind_cons <- lag(data$ind_brazil_constant, n = 4)[-(1:l)]

# Estimates the same especification as the second stage before, but using 
#    Terms of Trade instead of RER
# This is column (2) of Table 1
second_stage_cons_time_tot <- lm(data = data[-(1:l),],
                                 formula = ind_brazil_constant ~ lag_ind_cons + 
                                   lag2_ind_cons + 
                                   lag3_ind_cons + 
                                   lag4_ind_cons +
                                   ind_oecd_constant +
                                   lag3_tot_cons + 
                                   time_trend + 
                                   as.factor(quarter)
)

# Estimate the second stage of the IV using iv_robust.
#    It takes the third lag of the RER as the endogenous variable and uses the 
#    third lag of TOT, RBDI and the external shocks as instruments for the RER.
# This is column (3) of Table 1
second_stage_cons_time_rer_iv <- estimatr::iv_robust(data = data,
                                                     formula = ind_brazil_constant ~ 
                                                       lag(ind_brazil_constant, 1) + 
                                                       lag(ind_brazil_constant, 2) + 
                                                       lag(ind_brazil_constant, 3) + 
                                                       lag(ind_brazil_constant, 4) +
                                                       ind_oecd_constant +
                                                       time_trend + 
                                                       as.factor(quarter) + 
                                                       lag(rer,3) | 
                                                       lag(ind_brazil_constant, 1) + 
                                                       lag(ind_brazil_constant, 2) + 
                                                       lag(ind_brazil_constant, 3) + 
                                                       lag(ind_brazil_constant, 4) +
                                                       ind_oecd_constant +
                                                       time_trend + 
                                                       as.factor(quarter) + 
                                                       lag(tot,3) + 
                                                       lag(rbdi,3) + 
                                                       lag(d_managed,3) + 
                                                       lag(d_lula,3) + 
                                                       lag(d_covid,3)
) 

# This is column (2) of Table B1

second_stage_cons_time_reer_iv <- estimatr::iv_robust(data = data,
                                                     formula = ind_brazil_constant ~ 
                                                       lag(ind_brazil_constant, 1) + 
                                                       lag(ind_brazil_constant, 2) + 
                                                       lag(ind_brazil_constant, 3) + 
                                                       lag(ind_brazil_constant, 4) +
                                                       ind_oecd_constant +
                                                       lag(reer,3) + 
                                                       time_trend + 
                                                       as.factor(quarter) | 
                                                       lag(ind_brazil_constant, 1) + 
                                                       lag(ind_brazil_constant, 2) + 
                                                       lag(ind_brazil_constant, 3) + 
                                                       lag(ind_brazil_constant, 4) +
                                                       ind_oecd_constant +
                                                       time_trend + 
                                                       as.factor(quarter) + 
                                                       lag(tot,3) + 
                                                       lag(rbdi,3) + 
                                                       lag(d_managed,3) + 
                                                       lag(d_lula,3) + 
                                                       lag(d_covid,3)
) 

# Create a new row to be used as labels for Table 1
label_row <- data.frame("estimate" = "",
                        "RER" = "(1)", 
                        "1" = "(2)",
                        "2" = "(3)")

# Assign the position of the extra row to Table 1
attr(label_row, "position") <- 0

# Avoid modelsummary to output numbers as \num{}
options("modelsummary_format_numeric_latex" = "plain")

# Create a LaTeX table using the modelsummary package
table_1 <- modelsummary::modelsummary(
  models = list(
    "RER" = first_stage_cons,
    "BR Ind. Rate - Con." = second_stage_cons_time_tot,
    "BR Ind. Rate - Con." = second_stage_cons_time_rer_iv
  ),
  coef_map = c("(Intercept)" = "Constant",
               "tot" = "Terms of Trade",
               "rbdi" = "Real Broad Dollar Index",
               "d_managed" = "Dummy Managed",
               "d_lula" = "Dummy Lula",
               "d_covid" = "Dummy Covid",
               "lag(ind_brazil_constant, 1)" = "1st Lag BR Ind.Rate", 
               "lag(ind_brazil_constant, 2)" = "2nd Lag BR Ind.Rate",
               "lag(ind_brazil_constant, 3)" = "3rd Lag BR Ind.Rate",
               "lag(ind_brazil_constant, 4)" = "4th Lag BR Ind.Rate",
               "lag_ind_cons" = "1st Lag BR Ind.Rate",
               "lag2_ind_cons" = "2nd Lag BR Ind.Rate",
               "lag3_ind_cons" = "3rd Lag BR Ind.Rate",
               "lag4_ind_cons" = "4th Lag BR Ind.Rate",
               "lag3_tot_cons" = "3rd Lag Terms of Trade",
               "lag(rer, 3)" = "3rd Lag Fitted RER",
               "lag(reer, 1)" = "1st Lag Fitted REER",
               "lag(reer, 2)" = "2nd Lag Fitted REER",
               "lag(reer, 3)" = "3rd Lag Fitted REER",
               "lag(reer, 4)" = "4th Lag Fitted REER",
               "ind_oecd_constant" = "OECD Ind.Rate",
               "time_trend" = "Time Trend",
               "as.factor(quarter)1" = "1st Quarter",
               "as.factor(quarter)2" = "2nd Quarter",
               "as.factor(quarter)3" = "3rd Quarter",
               "as.factor(quarter)4" = "4th Quarter"
  ),
  stars = T,                                           # Include stars
  statistic = "p.value",                               # P-values between parentheses
  add_rows = label_row,                                # Add label row
  note = "P-Values between parentheses.",              # Add a note
  output = "latex",                                    # LaTeX output
  gof_omit = "AIC|BIC|Log|F",                          # Omit unecessary statistics
  escape = TRUE) %>%                                   # Avoid LaTeX errors
  kable_styling(latex_options = c("HOLD_position"))    
  
cat(table_1, file = "output//table_1.tex")  # Save file

# Create a new row to be used as labels for the Table B1
label_row_b1 <- data.frame("estimate" = "", "REER" = "(1)",
                        "1" = "(2)")

# Assign the position of the extra row to Table B1
attr(label_row_b1, "position") <- 0

# Create a LaTeX table using the modelsummary package
table_b1 <- modelsummary::modelsummary(
  models = list(
    "REER" = first_stage_cons_reer,
    "BR Ind. Rate - Con." = second_stage_cons_time_reer_iv
  ),
  coef_map = c("(Intercept)" = "Constant",
               "tot" = "Terms of Trade",
               "rbdi" = "Real Broad Dollar Index",
               "d_managed" = "Dummy Managed",
               "d_lula" = "Dummy Lula",
               "d_covid" = "Dummy Covid",
               "lag(ind_brazil_constant, 1)" = "1st Lag BR Ind.Rate", 
               "lag(ind_brazil_constant, 2)" = "2nd Lag BR Ind.Rate",
               "lag(ind_brazil_constant, 3)" = "3rd Lag BR Ind.Rate",
               "lag(ind_brazil_constant, 4)" = "4th Lag BR Ind.Rate",
               "lag_ind_cons" = "1st Lag BR Ind.Rate",
               "lag2_ind_cons" = "2nd Lag BR Ind.Rate",
               "lag3_ind_cons" = "3rd Lag BR Ind.Rate",
               "lag4_ind_cons" = "4th Lag BR Ind.Rate",
               "lag3_tot_cons" = "3rd Lag Terms of Trade",
               "lag(rer, 3)" = "3rd Lag Fitted RER",
               "lag(reer, 1)" = "1st Lag Fitted REER",
               "lag(reer, 2)" = "2nd Lag Fitted REER",
               "lag(reer, 3)" = "3rd Lag Fitted REER",
               "lag(reer, 4)" = "4th Lag Fitted REER",
               "ind_oecd_constant" = "OECD Ind.Rate",
               "time_trend" = "Time Trend",
               "as.factor(quarter)1" = "1st Quarter",
               "as.factor(quarter)2" = "2nd Quarter",
               "as.factor(quarter)3" = "3rd Quarter",
               "as.factor(quarter)4" = "4th Quarter"
  ),
  stars = T,                                           # Include stars
  statistic = "p.value",                               # P-values between parentheses
  add_rows = label_row_b1,                                # Add label row
  note = "P-Values between parentheses.",              # Add a note
  output = "latex",                                    # LaTeX output
  gof_omit = "AIC|BIC|Log|F",                          # Omit unecessary statistics
  escape = TRUE) %>%                                   # Avoid LaTeX errors
  kable_styling(latex_options = c("HOLD_position"))


cat(table_b1, file = "output//table_b1.tex")  # Save file


########################
####  ACF and PACF  ####
########################

widthcf <- 16             # Define plot width 
heightcf <- 5             # Define plot height
fontsize <- 12            # Define font size
font <- "LM Roman 10"     # Define font        

# Plot Autocorrelation Function (ACF) - TOT - Figure A1
acf_tot <- forecast::ggAcf(second_stage_cons_time_tot$residuals, lwd = 3) +
  theme(text=element_text(family=font, size=fontsize)) +
  ylab("ACF") + xlab("Lag") + theme_bw() +
  ggtitle(element_blank())  +
  labs(caption = "Lagged Terms of Trade as Regressor") +
  scale_y_continuous(breaks = seq(-1,1, by = 0.1)) +
  scale_x_continuous(breaks = seq(0,20, by = 1))

# Save plot
ggsave(acf_tot, width = widthcf, height = heightcf, units = "cm",
       filename = "output//figA1.png")

# Plot Parcial Autocorrelation Function (PACF) - TOT - Figure A2
pacf_tot <- forecast::ggPacf(second_stage_cons_time_tot$residuals, lwd = 3) +
  theme(text=element_text(family=font, size=fontsize)) +
  ylab("PACF") + xlab("Lag") + theme_bw() +
  ggtitle(element_blank()) +
  labs(caption = "Lagged Terms of Trade as Regressor") +
  scale_y_continuous(breaks = seq(-1,1, by = 0.1)) +
  scale_x_continuous(breaks = seq(0,20, by = 1))

# Save plot
ggsave(pacf_tot, width = widthcf, height = heightcf, units = "cm",
       filename = "output//figA2.png")

# Plot Autocorrelation Function (ACF) - RER - Figure A3
acf_rer <- forecast::ggAcf(second_stage_cons_time_rer_iv$ei.iv, lwd = 3) +
  theme(text=element_text(family=font, size=fontsize)) +
  ylab("ACF") + xlab("Lag") + theme_bw() +
  ggtitle(element_blank())  +
  labs(caption = "Lagged Real Exchange Rate as Regressor") +
  scale_y_continuous(breaks = seq(-1,1, by = 0.1)) +
  scale_x_continuous(breaks = seq(0,20, by = 1))

# Save plot
ggsave(acf_rer, width = widthcf, height = heightcf, units = "cm",
       filename = "output//figA3.png")

# Plot Parcial Autocorrelation Function (PACF) - RER - Figure A4
pacf_rer <- forecast::ggPacf(second_stage_cons_time_rer_iv$ei.iv, lwd = 3) +
  theme(text=element_text(family=font, size=fontsize)) +
  ylab("PACF") + xlab("Lag") + theme_bw() +
  ggtitle(element_blank()) +
  labs(caption = "Lagged Real Exchange Rate as Regressor") +
  scale_y_continuous(breaks = seq(-1,1, by = 0.1)) +
  scale_x_continuous(breaks = seq(0,20, by = 1))

# Save plot
ggsave(pacf_rer, width = widthcf, height = heightcf, units = "cm", 
       filename = "output//figA4.png")

#####################
####  Ljung-Box  ####
#####################

# Make Ljung-Box tests for both second stage regressions with 10 lags
  # Column (2) of Table A1
lb_cons_tot <- Box.test(second_stage_cons_time_tot$residuals, lag = 10, type = "Ljung", fitdf = 2)
  # Column (3) of Table A1
lb_cons_rer <- Box.test(second_stage_cons_time_rer_iv$ei.iv, lag = 10, type = "Ljung", fitdf = 2)

# Change object class to properly make a table following helper_functions.R custom functions 
class(lb_cons_tot) <- "customhtest"
class(lb_cons_rer) <- "customhtest"

# Make Table A1 using modelsummary
ljung_box <- modelsummary(models = list("BR Ind. Rate Con. - TOT" = lb_cons_tot,
                                        "BR Ind. Rate Con. - RER" = lb_cons_rer),
                          statistic = "p.value", 
                          output = "latex", 
                          title = "Ljung-Box tests",
                          note =  "P-values under coefficients.",
                          escape = TRUE) %>%  
                kable_styling(latex_options = c("HOLD_position"))

# Save Table A1
cat(ljung_box, file = "output//table_a1.tex")

#########################
####  Engle-Granger  ####
#########################

# Engle-Granger test for first regression - Column (1) of Table A2
#    Performs a ADF test on the regression residuals
rer<-urca::ur.df(y = ts(first_stage_cons$residuals),
                 selectlags = "BIC",
                 type = "none")

# Engle-Granger test for second regression - Column (2) of Table A2
#    Performs a ADF test on the regression residuals
cons_tot<-urca::ur.df(y = ts(second_stage_cons_time_tot$residuals),
                      selectlags = "BIC",
                      type = "none")

# Engle-Granger test for third regression - Column (3) of Table A2
#    Performs a ADF test on the regression residuals
cons_rer<-urca::ur.df(y = ts(second_stage_cons_time_rer_iv$ei.iv),
                      selectlags = "BIC",
                      type = "none") 

# Make a table for the tests - Table A2
engle_granger <- modelsummary::modelsummary(models = list("RER" = rer,
                                                          "BR Ind. Rate Con. (TOT)" = cons_tot,
                                                          "BR Ind. Rate Con. (RER)" = cons_rer),
                                            estimate = "estimate", 
                                            statistic = "p.value",
                                            coef_map = c("z.lag.1" = "Test Statistic"),
                                            title = "Engle-Granger tests",
                                            note = "P-values under coefficients.",
                                            output = "latex",
                                            escape = TRUE)%>%  
  kable_styling(latex_options = c("HOLD_position"))

# Save Table A2
cat(engle_granger, file = "output//table_a2.tex")
