# Estimate New Data for US Manufacturing Value Added at 
#   Quarterly Frequency, for the 1995-2004 period based 
#   on the Quarterly data from 2005 to 2007 and Annual 
#   data from 1995-2004.

# The code will estimate a regression of the 12 quarters from 2005-2007
#    that will have quarterly dummies as regressors, to extract the 
#    mean effect of being in quarter i. Call it D_i.

# Then it will create quarter Q1 based on the assumption that 
#    Annual Manufacturing VA is the following
#    ManuAnnual = ManuQ1 + ManuQ2 + ManuQ3 + ManuQ4 

# If we assume that ManuQq = (1 + D_q)ManuQ1, we get:
#    ManuAnnual = ManuQ1 + (1 + D_2)ManuQ1 + (1 + D_3)ManuQ1 + (1 + D_4)ManuQ1 

# Therefore, if we have ManuAnnual, and D_2, D_3, D_4 we 
#    can calculate ManuQ1:
#    ManuQ1 = ManuAnnual*4/(1 + (1+D_2) + (1+D_3) + (1+D_4))

# We include the 4 because Quarterly Data is at Annual USD.

# After calculating Q1, we can calculate ManuQ_q:
# ManuQ_q = (1+D_q)ManuQ1

library(tidyverse)
library(readxl)
library(magrittr)

# Read USA Manufacturing Value Added Quarterly Data retieved from BEA
#   and filter it for years before 2008 to avoid bias caused by the crisis
data_usa_manu_tri <- read_xlsx("usa_quarterly_data.xlsx",
                       col_names = TRUE) %>%
  mutate(year = str_split_i(time, pattern = "-", i = 1),
         quarter = str_split_i(time, pattern = "-", i = 2)) %>%
  filter(as.integer(year) < 2008)

# Run regression for current data to extract Quarterly Dummies
# That will estimate current quarterly data
curr <- lm(data = data_usa_manu_tri, 
           formula = log(manufacturing_current) ~ as.factor(quarter))

# Run regression for volume data to extract Quarterly Dummies
# That will estimate volume quarterly data
vol <- lm(data = data_usa_manu_tri, 
           formula = log(manufacturing_volume) ~ as.factor(quarter))

# Calculating the factor that will multiply the annual value of manufacturing VA
#   to estimate the Q1 value for each year

# The factor is 4/(1 + (1+D2) + (1+D3) + (1+D4))

# Which is true if we assume that the annual value is:
# A*4 = (Q1 + Q2 + Q3 + Q4)
# A*4 = Q1 + (1+D2)Q1 + (1+D3)Q1 + (1+D4)Q1
# A*4 = Q1(1 + (1+D2) + (1+D3) + (1+D4))
# A*4/(1 + (1+D2) + (1+D3) + (1+D4)) = Q1

factor_curr = 4/((1) + (1 + curr$coefficients[2]) + (1 + curr$coefficients[3]) + (1 + curr$coefficients[4])) 

factor_vol = 4/((1) + (1 + vol$coefficients[2]) + (1 + vol$coefficients[3]) + (1 + vol$coefficients[4])) 

# Reading Annual US Manufacturing VA data
# Multiplying by 1000 to convert it from USD Billions to USD Millions
data_usa_manu_anu <- read_xlsx("annual_us_manufacturing.xlsx",
                                col_names = TRUE) %>%
  mutate(manu_current = manu_current*1000,
         manu_volume = manu_volume*1000)

# Create data-frame that will receive new estimated data
new_data <- data.frame(time = paste0(rep(1995:2005,4), 
                                        "-Q", 1:4)) %>%
  arrange(time) %>% # Arrange by time
  mutate(year = as.integer(str_split_i(time,                      # Create year variable
                                       pattern = "-", i = 1)),    #
         quarter = as.integer(str_split_i(time,                         # Create quarter variable
                                          pattern = "-Q", i = 2))) %>%  #
  left_join(data_usa_manu_anu, by = "year") %>%        # Join Annual data (repeating data from a given year into its quarters)
  mutate(current = manu_current * factor_curr,          # Estimate Current ManuQ1
         volume = manu_volume * factor_vol) %>%         # Estimate Volume ManuQ1
  mutate(current = 
           case_when(quarter == 2 ~ current * (1+curr$coefficients[2]),   # Estimate Current ManuQ2
                     quarter == 3 ~ current * (1+curr$coefficients[3]),   # Estimate Current ManuQ3
                     quarter == 4 ~ current * (1+curr$coefficients[4]),   # Estimate Current ManuQ4
                     T ~ current
           ),
         volume = 
           case_when(quarter == 2 ~ volume * (1+vol$coefficients[2]),   # Estimate Volume ManuQ2
                     quarter == 3 ~ volume * (1+vol$coefficients[3]),   # Estimate Volume ManuQ3
                     quarter == 4 ~ volume * (1+vol$coefficients[4]),   # Estimate Volume ManuQ4
                     T ~ volume
           ))

# From now on, the code will merge Estimated US Quarterly Manufacturing VA data from 1995Q1-2004Q4 
#    with BEA US Quarterly Manufacturing VA data
# 

# Read USD-PPP GDP Current and Volume data and filter to the US
# Create Year and Quarter variables
data_gdp_us <- read_csv("GDP_USD_Luiz.csv") %>%
  rename(country = "Reference area",                                # Rename variables
         price = "Price base",                                      
         unit = "Unit of measure",                                  
         time = "TIME_PERIOD",                                      
         gdp = "OBS_VALUE") %>%                                     
  select(country, time, price, gdp) %>%
  mutate(price = case_when(price == "Current prices" ~                # Rename price observations
                             "gdp_current",                           
                           price == "Chain linked volume (rebased)" ~ # Rename price observations
                             "gdp_volume")) %>%                       
  filter(country == "United States") %>%
  mutate(year = as.integer(substr(time, 1,4)),        # Create year variable
         quarter = as.integer(substr(time, 7, 7)))    # Create quarter variable

# Calculate Implicit price to bring Volume GDP Data to 2005 Prices, which is the
#     same Reference year as the Volume Manufacturing Data Reference year

implicit_p <- data_gdp_us$gdp[data_gdp_us$year == 2005 & data_gdp_us$quarter == 1 & data_gdp_us$price == "gdp_current"]/
  data_gdp_us$gdp[data_gdp_us$year == 2005 & data_gdp_us$quarter == 1 & data_gdp_us$price == "gdp_volume"]


# Make it a wide dataframe to make it easier to calculate 
#   Manufacturing VA Share of GDP. Convert values to 2005 prices

data_gdp_us %<>%
  pivot_wider(id_cols = c("time", "year", "quarter"),
              names_from = price,
              values_from = gdp) %>%
  mutate(gdp_volume = gdp_volume*implicit_p) %>%
  filter(as.integer(year) < 2005)

new_data %<>% select(time, year, quarter, current, volume) %>%
  rename(manufacturing_current = current,
         manufacturing_volume = volume) %>%
  left_join(data_gdp_us, by = c("time", "year", "quarter")) %>%
  mutate(current = manufacturing_current/gdp_current,
         volume = manufacturing_volume/gdp_volume,
         type = "estimated")

new_data$country <- "United States"
